@@ -794,14 +794,14 @@ run_mount_mountable (GVfsBackendSmbBrowse *backend,
 	  g_mount_spec_unref (mount_spec);
 	}
       else
-	g_set_error (&error,
-		     G_IO_ERROR, G_IO_ERROR_NOT_MOUNTABLE_FILE,
-		     "%s", _("The file is not a mountable"));
+	g_set_error_literal (&error,
+			     G_IO_ERROR, G_IO_ERROR_NOT_MOUNTABLE_FILE,
+			     _("The file is not a mountable"));
     }
   else
-    g_set_error (&error,
-		 G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
-		 "%s", _("File doesn't exist"));
+    g_set_error_literal (&error,
+			 G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
+			 _("File doesn't exist"));
       
   g_mutex_unlock (backend->entries_lock);
 
@@ -1067,7 +1067,6 @@ try_query_info (GVfsBackend *backend,
 		GFileAttributeMatcher *matcher)
 {
   GVfsBackendSmbBrowse *op_backend = G_VFS_BACKEND_SMB_BROWSE (backend);
-  const char *icon_name;
   GIcon *icon;
 
   if (is_root (filename))
@@ -1075,13 +1074,9 @@ try_query_info (GVfsBackend *backend,
       g_file_info_set_file_type (info, G_FILE_TYPE_DIRECTORY);
       g_file_info_set_name (info, "/");
       g_file_info_set_display_name (info, g_vfs_backend_get_display_name (backend));
-      icon_name = g_vfs_backend_get_icon_name (backend);
-      if (icon_name)
-	{
-	  icon = g_themed_icon_new (icon_name);
-	  g_file_info_set_icon (info, icon);
-	  g_object_unref (icon);
-	}
+      icon = g_vfs_backend_get_icon (backend);
+      if (icon != NULL)
+        g_file_info_set_icon (info, icon);
       g_vfs_job_succeeded (G_VFS_JOB (job));
       
       return TRUE;
