@@ -212,7 +212,10 @@ g_proxy_mount_update (GProxyMount         *mount,
   /* in with the new */
   mount->id = g_strdup (id);
   mount->name = g_strdup (name);
-  mount->icon = _g_icon_new_from_serialized_data (gicon_data);
+  if (*gicon_data == 0)
+    mount->icon = NULL;
+  else
+    mount->icon = g_icon_new_for_string (gicon_data, NULL);
   mount->uuid = g_strdup (uuid);
   mount->root = g_file_new_for_uri (root_uri);
   mount->can_unmount = can_unmount;
@@ -361,6 +364,7 @@ eject_wrapper_callback (GObject *source_object,
 {
   EjectWrapperOp *data  = user_data;
   data->callback (data->object, res, data->user_data);
+  g_object_unref (data->object);
   g_free (data);
 }
 
@@ -379,7 +383,7 @@ g_proxy_mount_eject (GMount              *mount,
     {
       EjectWrapperOp *data;
       data = g_new0 (EjectWrapperOp, 1);
-      data->object = G_OBJECT (mount);
+      data->object = g_object_ref (mount);
       data->callback = callback;
       data->user_data = user_data;
       g_drive_eject (drive, flags, cancellable, eject_wrapper_callback, data);
